import { FormModel, IFormModelItem, FormGroups, FormGroupItem } from './types';
import { UnwrapNestedRefs } from '@vue/reactivity';
export declare type FormStoreInitialConfig = ConstructorParameters<typeof FormStore>[number];
declare class FormStore {
    /**
     * 表单数据模型
     */
    models: UnwrapNestedRefs<Map<string, IFormModelItem>>;
    /**
     * 表单原始数据
     */
    private originalModel;
    /**
     * 分组信息
     */
    groups: UnwrapNestedRefs<Map<string, FormGroupItem & {
        items: string[];
    }>>;
    /**
     * 是否为分组模式
     */
    isGroupMode: boolean;
    /**
     * 校验失败错误信息
     */
    errorMessages: UnwrapNestedRefs<Record<string, string>>;
    constructor(options: {
        models: FormModel;
        groups?: FormGroups;
    });
    /**
     * 解析分组信息
     * @param groups 分组列表
     * @param models 表单数据模型
     */
    private resolveGroups;
    /**
     * 更新数据
     * @param data
     */
    updateData: (data: Record<string, unknown>) => void;
    /**
     * 更新单个 item 信息
     * @param key
     * @param item
     */
    updateItem: (key: string, item: Partial<IFormModelItem>) => void;
    /**
     * 获取单个 item 信息
     * @param name 字段名
     */
    getItem: (name: string) => IFormModelItem<unknown, Record<string, any>> | undefined;
    /**
     *
     * @returns 获取表单数据
     */
    getFormData: () => {};
    /**
     * 表单重置
     */
    reset: () => void;
    /**
     * 表单校验
     */
    validate: () => Promise<unknown>;
    /**
     * 单个校验
     * @param name 字段名
     */
    singleValidate: (name: string) => void;
    /**
     * 清空所有校验信息
     */
    private clearMessages;
    convertModel: () => IFormModelItem<unknown, Record<string, any>>[];
}
export { FormStore };
